/// <reference types="node" />
import FormData from './formdata';
import EventHandler from './html/eventhandler';
import XMLHttpRequestEventTarget from './xmlhttprequesteventtarget';
import XMLHttpRequestUpload from './xmlhttprequestupload';
export declare type BodyInit = ArrayBuffer | Buffer | FormData | URLSearchParams | Uint8Array | string;
export declare type XMLHttpRequestResponseType = '' | 'arraybuffer' | 'blob' | 'document' | 'json' | 'text';
/**
 * @see {@link https://xhr.spec.whatwg.org/#interface-xmlhttprequest XMLHttpRequest Standard - 4. Interface XMLHttpRequest}
 */
export default class XMLHttpRequest extends XMLHttpRequestEventTarget {
    #private;
    static readonly UNSENT = 0;
    static readonly OPENED = 1;
    static readonly HEADERS_RECEIVED = 2;
    static readonly LOADING = 3;
    static readonly DONE = 4;
    readonly UNSENT = 0;
    readonly OPENED = 1;
    readonly HEADERS_RECEIVED = 2;
    readonly LOADING = 3;
    readonly DONE = 4;
    readonly upload: XMLHttpRequestUpload;
    get onreadystatechange(): EventHandler | null;
    set onreadystatechange(value: EventHandler | null);
    get readyState(): number;
    get response(): ArrayBufferLike | Buffer | string | any | null;
    get responseText(): string;
    get responseType(): XMLHttpRequestResponseType;
    set responseType(value: XMLHttpRequestResponseType);
    get responseURL(): string;
    get responseXML(): null;
    get status(): number;
    get statusText(): string;
    get timeout(): number;
    set timeout(value: number);
    get withCredentials(): boolean;
    set withCredentials(value: boolean);
    constructor();
    /**
     * @see {@link https://xhr.spec.whatwg.org/#the-abort()-method XMLHttpRequest Standard - 4.5.7. The abort() method}
     */
    abort(): void;
    /**
     * @see {@link https://xhr.spec.whatwg.org/#the-getallresponseheaders()-method XMLHttpRequest Standard - 4.6.5. The getAllResponseHeaders() method}
     */
    getAllResponseHeaders(): string;
    /**
     * @see {@link https://xhr.spec.whatwg.org/#the-getresponseheader()-method XMLHttpRequest Standard - 4.6.4. The getResponseHeader() method}
     */
    getResponseHeader(name: string): string | null;
    /**
     * @see {@link https://xhr.spec.whatwg.org/#the-open()-method 4.5.1. The open() method}
     */
    open(method: string, url: string, async?: boolean, username?: string | null, password?: string | null): void;
    /**
     * @see {@link https://xhr.spec.whatwg.org/#the-overridemimetype()-method XMLHttpRequest Standard - 4.6.7. The overrideMimeType() method}
     */
    overrideMimeType(mime: string): void;
    /**
     * @see {@link https://xhr.spec.whatwg.org/#the-send()-method XMLHttpRequest Standard - 4.5.6. The send() method}
     */
    send(body?: BodyInit | null): void;
    /**
     * @see {@link https://xhr.spec.whatwg.org/#the-setrequestheader()-method XMLHttpRequest Standard - 4.5.2. The setRequestHeader() method}
     */
    setRequestHeader(name: string, value: string): void;
}
